==> igniteui-webcomponents-core-3.5.0.tgz: package/esm5/lib/OperatorSelectorOpeningEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { OperatorSelectorOpeningEventArgsDescription } from "./OperatorSelectorOpeningEventArgsDescription";
/**
 * @hidden
 */
var OperatorSelectorOpeningEventArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(OperatorSelectorOpeningEventArgsDescriptionMetadata, _super);
    function OperatorSelectorOpeningEventArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    OperatorSelectorOpeningEventArgsDescriptionMetadata.b = function (a) {
        if (OperatorSelectorOpeningEventArgsDescriptionMetadata.a == null) {
            OperatorSelectorOpeningEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            OperatorSelectorOpeningEventArgsDescriptionMetadata.c(OperatorSelectorOpeningEventArgsDescriptionMetadata.a);
        }
        if (a.j(OperatorSelectorOpeningEventArgsDescriptionMetadata.a)) {
            return;
        }
        a.y(OperatorSelectorOpeningEventArgsDescriptionMetadata.a);
    };
    OperatorSelectorOpeningEventArgsDescriptionMetadata.c = function (a) {
    };
    OperatorSelectorOpeningEventArgsDescriptionMetadata.d = function (a) {
        OperatorSelectorOpeningEventArgsDescriptionMetadata.b(a);
        a.aa("OperatorSelectorOpeningEventArgs", function () { return new OperatorSelectorOpeningEventArgsDescription(); });
        a.z("OperatorSelectorOpeningEventArgs", OperatorSelectorOpeningEventArgsDescriptionMetadata.a);
    };
    OperatorSelectorOpeningEventArgsDescriptionMetadata.$t = markType(OperatorSelectorOpeningEventArgsDescriptionMetadata, 'OperatorSelectorOpeningEventArgsDescriptionMetadata');
    OperatorSelectorOpeningEventArgsDescriptionMetadata.a = null;
    return OperatorSelectorOpeningEventArgsDescriptionMetadata;
}(Base));
export { OperatorSelectorOpeningEventArgsDescriptionMetadata };

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm5/lib/OperatorSelectorOpeningEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { OperatorSelectorOpeningEventArgsDescription } from "./OperatorSelectorOpeningEventArgsDescription";
/**
 * @hidden
 */
var OperatorSelectorOpeningEventArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(OperatorSelectorOpeningEventArgsDescriptionMetadata, _super);
    function OperatorSelectorOpeningEventArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    OperatorSelectorOpeningEventArgsDescriptionMetadata.b = function (a) {
        if (OperatorSelectorOpeningEventArgsDescriptionMetadata.a == null) {
            OperatorSelectorOpeningEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            OperatorSelectorOpeningEventArgsDescriptionMetadata.c(OperatorSelectorOpeningEventArgsDescriptionMetadata.a);
        }
        if (a.k(OperatorSelectorOpeningEventArgsDescriptionMetadata.a)) {
            return;
        }
        a.aa(OperatorSelectorOpeningEventArgsDescriptionMetadata.a);
    };
    OperatorSelectorOpeningEventArgsDescriptionMetadata.c = function (a) {
    };
    OperatorSelectorOpeningEventArgsDescriptionMetadata.d = function (a) {
        OperatorSelectorOpeningEventArgsDescriptionMetadata.b(a);
        a.ac("OperatorSelectorOpeningEventArgs", function () { return new OperatorSelectorOpeningEventArgsDescription(); });
        a.ab("OperatorSelectorOpeningEventArgs", OperatorSelectorOpeningEventArgsDescriptionMetadata.a);
    };
    OperatorSelectorOpeningEventArgsDescriptionMetadata.$t = markType(OperatorSelectorOpeningEventArgsDescriptionMetadata, 'OperatorSelectorOpeningEventArgsDescriptionMetadata');
    OperatorSelectorOpeningEventArgsDescriptionMetadata.a = null;
    return OperatorSelectorOpeningEventArgsDescriptionMetadata;
}(Base));
export { OperatorSelectorOpeningEventArgsDescriptionMetadata };
